from absorb.core.tasks import commands as tasks_group
from absorb.core.kanban import commands as kanban_group
from absorb.core.idea import commands as idea_group

from pkg_resources import iter_entry_points

import click
from click_plugins import with_plugins


@with_plugins(iter_entry_points("absorb.plugins"))
@click.group()
def cli() -> None:
    """Creates the main click group for absorb."""
    pass


cli.add_command(tasks_group.tasks)
cli.add_command(kanban_group.kanban)
cli.add_command(idea_group.idea)

if __name__ == "__main__":
    cli()



import click
import os
import json
import git
from pathlib import Path
from rich.console import Console
from ...utils import idea_utils, log_utils
from ...config.paths import ROOT_PATH, REPO_PATH


repo = git.Repo.init(str(REPO_PATH))
logger = log_utils.get_logger()

console = Console()

idea_path = ROOT_PATH / "ideas.json"


@click.group()
def idea() -> None:
    """The main click group for idea."""

    pass


@idea.command()
@click.argument("name")
@click.argument("description")
@click.argument("tags")
def new(name: str, description: str, tags: str) -> None:
    """Adds a new idea to ideas.json and commits the idea to the git repository.

    :param name: Name of the idea.
    :type name: str
    :param description: Description of the idea.
    :type description: str
    :param tags: Tags for the idea.
    :type tags: str
    :rtype: None
    """

    words = tags.split(" ")
    extracted_tags = [word[1:] for word in words if word[0] == "@"]

    description = description.strip()
    try:
        with idea_path.open("r") as ideas_file:
            ideas_json = json.load(ideas_file)
            card_id = len([idea for idea in ideas_json]) + 1
            if description == "+file":
                description_file_name = input("Enter file path to load description: ")
                content = {
                    "id": ("#" + str(card_id)),
                    "name": name,
                    "description": os.fspath(Path(description_file_name)),
                    "tags": extracted_tags,
                }
            else:
                content = {
                    "id": ("#" + str(card_id)),
                    "name": name,
                    "description": description,
                    "tags": extracted_tags,
                }

            ideas_json.append(content)

            with idea_path.open("w") as ideas_file:
                ideas_json = json.dump(ideas_json, ideas_file)
                console.print(
                    f':white_check_mark: "{name}" has been added to the list!'
                )

            repo.index.add([str(REPO_PATH / "ideas.json")])
            repo.index.commit(f'Added idea "{name}"')
    except FileNotFoundError as e:
        with idea_path.open("a") as ideas_file:
            ideas_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@idea.command()
@click.argument("id")
@click.argument("name")
@click.argument("description")
@click.argument("tags")
def edit(id: str, name: str, description: str, tags: str) -> None:
    """Edits an existing idea in ideas.json and commits the changes in the git repository.

    :param id: ID of the idea.
    :type id: str
    :param name: Name of the idea.
    :type name: str
    :param description: Description of the idea.
    :type description: str
    :param tags: Tags for the idea.
    :type tags: str
    :rtype: None
    """

    words = tags.split(" ")
    extracted_tags = [word[1:] for word in words if word[0] == "@"]

    try:
        with idea_path.open("r") as idea_file:
            idea_json = json.load(idea_file)
            filtered_idea = idea_json

            for card in filtered_idea:
                if card["id"] == id:
                    if name.strip() != ".":
                        card["name"] = name

                    if description.strip() == "+file":
                        description_file_name = input(
                            "Enter file path to load description: "
                        )

                        card["description"] = os.fspath(Path(description_file_name))
                    else:
                        if description != ".":
                            card["description"] = description

                    if tags.strip() != ".":
                        card["tags"] = extracted_tags

            with idea_path.open("w") as idea_file:
                filtered_idea = json.dump(filtered_idea, idea_file)
                console.print(
                    f":white_check_mark: Card {id} has been modified in the idea!"
                )
                repo.index.add([str(idea_path)])
                repo.index.commit(f"Modified Card {id} in the idea board.")
                console.print(
                    f":white_check_mark: Card {id} has been modified in the git repository!"
                )

    except FileNotFoundError as e:
        with idea_path.open("a") as idea_file:
            idea_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@idea.command()
@click.argument("id")
def open(id: str) -> None:
    """Opens an idea present in ideas.json

    :param id: ID of the idea.
    :type id: str
    :rtype: None
    """

    try:
        with idea_path.open("r") as idea_file:
            idea_content = json.load(idea_file)
            filtered_ideas = []
            for idea in idea_content:
                if idea["id"] == id:
                    filtered_ideas.append(idea)
            idea_utils.open_idea(filtered_ideas)
    except FileNotFoundError as e:
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )


@idea.command()
def show() -> None:
    """Shows all ideas present in ideas.json"""

    try:
        with idea_path.open("r") as ideas_file:
            idea_content = json.load(ideas_file)
            idea_utils.parse_ideas(idea_content)
    except FileNotFoundError as e:
        with idea_path.open("a") as idea_file:
            idea_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )



from typing import Any
from rich.table import Table
from rich.console import Console
from pathlib import Path

kanban_board = Table(show_header=True, header_style="bold")
kanban_board.add_column("Completed")
kanban_board.add_column("Doing")
kanban_board.add_column("Planned")

console = Console()


def parse_card(card: Any) -> str:
    """Returns a string containing the card content.

    :param card: JSON object containing data for the card.
    :type card: Any
    :return: Formatted string with the card.
    :rtype: str
    """

    card_id = card["id"]
    card_name = card["name"]
    card_tags = card["tags"]
    card_description_path = Path(card["description"])

    card_description = card["description"]

    if card_description != ".":
        try:
            if card_description_path.is_file():
                with card_description_path.open("r") as card_description_file:
                    card_description = "".join(card_description_file.readlines())
        except FileNotFoundError:
            console.print(
                ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
            )
        return f"[bold red]{card_id}[/bold red]\n{card_name}\n[bold yellow]\ndescription:\n{card_description}\ntags: {card_tags}[/bold yellow]\n"
    else:
        return f"[bold red]{card_id}[/bold red]\n{card_name}\n[bold yellow]tags: {card_tags}[/bold yellow]\n"


def parse_kanban(content: Any) -> None:
    """Prints the kanban board.

    :param content: File content containing cards.
    :type content: Any
    :rtype: None
    """

    cards = {"completed": [], "doing": [], "planned": []}

    for task in content:
        card = task
        # print(task)
        if card["status"] == "completed":
            cards["completed"].append(card)
        elif card["status"] == "doing":
            cards["doing"].append(card)
        elif card["status"] == "planned":
            cards["planned"].append(card)

    completed_cards = "\n".join([parse_card(card) for card in cards["completed"]])
    doing_cards = "\n".join([parse_card(card) for card in cards["doing"]])
    planned_cards = "\n".join([parse_card(card) for card in cards["planned"]])
    kanban_board.add_row(completed_cards, doing_cards, planned_cards)
    console.print(kanban_board)



from typing import Any
from rich.table import Table
from rich.console import Console
from datetime import datetime, timedelta
from collections import namedtuple

console = Console()


def convert_timedelta(duration: timedelta) -> namedtuple:
    """Converts a timedelta object into the custom ExtractedDate namedtuple.

    :param duration: Timedelta object for date.
    :type duration: timedelta
    :return: ExtractedDate namedtuple.
    :rtype: namedtuple
    """

    date_tuple = namedtuple("ExtractedDate", ["days", "hours", "minutes", "seconds"])
    days, seconds = duration.days, duration.seconds
    hours = days * 24 + seconds // 3600
    minutes = (seconds % 3600) // 60
    seconds = seconds % 60
    return date_tuple(days, hours, minutes, seconds)


def parse_tasks(file_content: Any) -> None:
    """Prints the tasks table.

    :param file_content: File content containing tasks.
    :type file_content: Any
    :rtype: None
    """

    tasks_table = Table(show_header=True, header_style="bold")
    tasks_table.add_column("Task ID")
    tasks_table.add_column("Task Name")
    tasks_table.add_column("Date Added")
    tasks_table.add_column("Due Date")
    tasks_table.add_column("Priority")
    tasks_table.add_column("Group")

    for task in file_content:
        task_entry = task

        task_date = datetime.strptime(task_entry["date"], "%Y-%m-%d %H:%M:%S.%f")

        task_due_date = datetime.strptime(
            task_entry["due_date"], "%Y-%m-%d %H:%M:%S.%f"
        )
        curr_date = datetime.now()

        diff = task_due_date - curr_date
        diff_date = convert_timedelta(diff)

        due_display = ""
        if (diff_date.days == 0) and (diff_date.hours < 24):
            due_display = "Due today."
        elif diff_date.days < 0:
            due_display = str(abs(diff_date.days)) + " days overdue."
        elif diff_date.days > 0:
            due_display = str(diff_date.days) + " days to due date."

        due_date = (
            datetime.strftime(task_due_date, "%b %d, %Y at %I:%M%p")
            + f"\n({due_display})"
        )

        if task_entry["group"] == "":
            tasks_table.add_row(
                task_entry["id"],
                task_entry["name"],
                datetime.strftime(task_date, "%b %d, %Y at %I:%M%p"),
                due_date,
                task_entry["priority"],
            )
        else:
            tags = task_entry["group"]
            tasks_table.add_row(
                task_entry["id"],
                task_entry["name"],
                datetime.strftime(task_date, "%b %d, %Y at %I:%M%p"),
                due_date,
                task_entry["priority"],
                f"[bold yellow]tags: {tags}[/bold yellow]",
            )

    console.print(tasks_table)



from rich.table import Table
from rich.console import Console
from pathlib import Path
from typing import Any

console = Console()


def parse_ideas(file_content: Any) -> None:
    """Prints the ideas table.

    :param file_content: File content containing ideas.
    :type file_content: Any
    :rtype: None
    """

    ideas_table = Table(show_header=True, header_style="bold")
    ideas_table.add_column("ID")
    ideas_table.add_column("Idea Name")
    ideas_table.add_column("Tags")
    for idea in file_content:
        idea_entry = idea
        tags = idea_entry["tags"]
        ideas_table.add_row(
            idea_entry["id"], idea_entry["name"], f"[bold yellow]{tags}[/bold yellow]"
        )

    console.print(ideas_table)


def parse_idea(idea: Any) -> str:
    """Returns a string containing the idea.

    :param idea: JSON object containing data for the idea.
    :type idea: Any
    :return: Formatted string with the idea.
    :rtype: str
    """

    idea_id = idea["id"]
    idea_name = idea["name"]
    idea_tags = idea["tags"]
    idea_description_path = Path(idea["description"])

    idea_description = idea["description"]

    if idea_description != ".":
        try:
            if idea_description_path.is_file():
                with idea_description_path.open("r") as idea_description_file:
                    idea_description = "".join(idea_description_file.readlines())
        except FileNotFoundError:
            console.print(
                ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
            )
        return f"\n[bold red]Idea ID: {idea_id}[/bold red]\n[bold magenta]{idea_name}[/bold magenta]\n\n[bold green]Idea Description:[/bold green]\n\n{idea_description}\n\n[bold yellow]Tags: {idea_tags}[/bold yellow]\n"
    else:
        return f"\n[bold red]Idea ID: {idea_id}[/bold red]\n[bold magenta]{idea_name}[/bold magenta]\n[bold yellow]Tags: {idea_tags}[/bold yellow]\n"


def open_idea(file_content: Any) -> None:
    """Prints the parsed idea.

    :param file_content: File content containing the idea.
    :type file_content: Any
    :rtype: None
    """

    for idea in file_content:
        console.print(parse_idea(idea))



from pathlib import Path
from ...utils import kanban_utils, log_utils
from ...config.paths import ROOT_PATH, REPO_PATH
import click
from rich.console import Console
import json
import git
import os

repo = git.Repo.init(str(REPO_PATH))
logger = log_utils.get_logger()

console = Console()

kanban_path = ROOT_PATH / "kanban.json"


@click.group()
def kanban() -> None:
    """Creates the main click group for kanban boards."""
    pass


@kanban.command()
@click.argument("name")
@click.argument("status")
@click.argument("description")
@click.argument("tags")
def add(name: str, status: str, description: str, tags: str) -> None:
    """Adds a card to the kanban board.

    :param name: Name of the card.
    :type name: str
    :param status: Status of the card.
    :type status: str
    :param description: Description of the card.
    :type description: str
    :param tags: Tags for the card.
    :type tags: str
    :rtype: None
    """

    words = tags.split(" ")
    extracted_tags = [word[1:] for word in words if word[0] == "@"]

    description = description.strip()
    try:
        with kanban_path.open("r") as kanban_file:
            kanban_json = json.load(kanban_file)

            card_id = len([card for card in kanban_json]) + 1
            if description == "+file":
                description_file_name = input("Enter file path to load description: ")
                content = {
                    "id": ("#" + str(card_id)),
                    "name": name,
                    "status": status.lower(),
                    "description": os.fspath(Path(description_file_name)),
                    "tags": extracted_tags,
                }
            else:
                content = {
                    "id": ("#" + str(card_id)),
                    "name": name,
                    "status": status.lower(),
                    "description": description,
                    "tags": extracted_tags,
                }
            kanban_json.append(content)

            with kanban_path.open("w") as kanban_file:
                kanban_json = json.dump(kanban_json, kanban_file)
                console.print(
                    f':white_check_mark: "{name}" has been added to the board!'
                )
    except FileNotFoundError as e:
        with kanban_path.open("a") as kanban_file:
            kanban_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@kanban.command()
@click.argument("id")
def delete(id: str) -> None:
    """Deletes a card from the kanban board.

    :param id: ID of the card.
    :type id: str
    :rtype: None
    """

    try:
        kanban_json = None
        with kanban_path.open("r") as kanban_file:
            kanban_json = json.load(kanban_file)

        filtered_kanban = [card for card in kanban_json if card["id"] != id]

        try:
            with kanban_path.open("w") as kanban_file:
                filtered_kanban = json.dump(filtered_kanban, kanban_file)
        except FileNotFoundError as e:
            logger.error(e)
            console.print(
                ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
            )

    except FileNotFoundError as e:
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )


@kanban.command()
@click.argument("id")
@click.argument("name")
@click.argument("description")
@click.argument("tags")
def edit(id: str, name: str, description: str, tags: str) -> None:
    """Edits a card in the kanban board.

    :param id: ID of the card.
    :type id: str
    :param name: Name of the card.
    :type name: str
    :param description: Description of the card.
    :type description: str
    :param tags: Tags for the card.
    :type tags: str
    :rtype: None
    """

    words = tags.split(" ")
    extracted_tags = [word[1:] for word in words if word[0] == "@"]

    try:
        with kanban_path.open("r") as kanban_file:
            kanban_json = json.load(kanban_file)
            filtered_kanban = kanban_json

            for card in filtered_kanban:
                if card["id"] == id:
                    if name.strip() != ".":
                        card["name"] = name

                    if description.strip() == "+file":
                        description_file_name = input(
                            "Enter file path to load description: "
                        )

                        card["description"] = os.fspath(Path(description_file_name))
                    else:
                        if description != ".":
                            card["description"] = description

                    if tags.strip() != ".":
                        card["tags"] = extracted_tags

            with kanban_path.open("w") as kanban_file:
                filtered_kanban = json.dump(filtered_kanban, kanban_file)
                console.print(
                    f":white_check_mark: Card {id} has been modified in the kanban!"
                )
                repo.index.add([str(kanban_path)])
                repo.index.commit(f"Modified Card {id} in the kanban board.")
                console.print(
                    f":white_check_mark: Card {id} has been modified in the git repository!"
                )

    except FileNotFoundError as e:
        with kanban_path.open("a") as kanban_file:
            kanban_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@kanban.command()
@click.argument("id")
@click.argument("new_status")
def move_card(id: str, new_status: str) -> None:
    """Moves a card to the specified status.

    :param id: ID of the card.
    :type id: str
    :param new_status: The new status to which the card should be moved to.
    :type new_status: str
    :rtype: None
    """

    try:
        kanban_json = None
        with kanban_path.open("r") as kanban_file:
            kanban_json = json.load(kanban_file)

        filtered_kanban = kanban_json

        for task in filtered_kanban:
            if task["id"] == id:
                task["status"] = new_status

        try:
            with kanban_path.open("w") as kanban_file:
                filtered_kanban = json.dump(filtered_kanban, kanban_file)
        except FileNotFoundError as e:
            logger.error(e)
            console.print(
                ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
            )

    except FileNotFoundError as e:
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )


@kanban.command()
def show() -> None:
    """Shows the kanban board."""

    try:
        with kanban_path.open("r") as kanban_file:
            kanban_content = json.load(kanban_file)
            kanban_utils.parse_kanban(kanban_content)
    except FileNotFoundError as e:
        with kanban_path.open("a") as kanban_file:
            kanban_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )



import click
import json
import git
import sys
from json.decoder import JSONDecodeError
from datetime import datetime, timedelta
from rich.console import Console
from typing import Any, TextIO
from ...config.paths import ROOT_PATH, REPO_PATH
from ...utils import tasks_utils, log_utils

repo = git.Repo.init(str(REPO_PATH))
logger = log_utils.get_logger()

console = Console()

tasks_path = ROOT_PATH / "tasks.json"


@click.group()
def tasks() -> None:
    """The main click group for tasks."""
    pass


def parse_date(date_str: str, *args: str) -> datetime:
    """Parses a date string and returns a datetime object after parsing the date string. The date string might contain some values which tells the function to shift the date by a particular period.

    :param date_str: Date string.
    :type date_str: str
    :param args: Optional arguments.
    :type args: str
    :return: Datetime object.
    :rtype: datetime
    """
    days_filtered = 0
    hours_filtered = 0
    minutes_filtered = 0
    seconds_filtered = 0

    if date_str == ".":
        return datetime.now()
    elif date_str[0] == "+" and len(date_str) > 1:
        token_list = date_str[1:].split()
        for token in token_list:
            if token[-1] == "d":
                days_filtered = int(token[:-1])
            elif token[-1] == "h":
                hours_filtered = int(token[:-1])
            elif token[-1] == "m":
                minutes_filtered = int(token[:-1])
            elif token[-1] == "s":
                seconds_filtered = int(token[:-1])
            else:
                pass

        if len(args) > 0:
            task_due_str = args[0]
            task_due_date = datetime.strptime(task_due_str, "%Y-%m-%d %H:%M:%S.%f")
            shifted_date = task_due_date + timedelta(
                days=float(days_filtered),
                hours=float(hours_filtered),
                minutes=float(minutes_filtered),
                seconds=float(seconds_filtered),
            )
        else:
            shifted_date = datetime.now() + timedelta(
                days=float(days_filtered),
                hours=float(hours_filtered),
                minutes=float(minutes_filtered),
                seconds=float(seconds_filtered),
            )

        return shifted_date
    elif len(date_str) > 1:
        try:
            task_date = datetime.strptime(date_str, "%Y-%m-%d %H:%M:%S.%f")
            return task_date
        except ValueError as e:
            logger.warning("Date string provided: " + date_str)
            logger.error(e)
            console.print(
                ":cross_mark: Invalid date string provided. Continued with current date as the due date. Check the logs in the home directory to know more."
            )
            return datetime.now()
    else:
        logger.warning("Date string provided: " + date_str)
        console.print(
            ":cross_mark: Invalid date string provided. Continued with current date as the due date. Check the logs in the home directory to know more."
        )
        return datetime.now()


def load_json(tasks_file: TextIO) -> Any:
    """Loads a file pointer and returns a JSON object. Used as a utility for checking any encoding/decoding while reading a JSON file.

    :param tasks_file: File pointer for the JSON file.
    :type tasks_file: TextIO
    :return: JSON object.
    :rtype: Any
    """
    tasks_json = None
    try:
        tasks_json = json.load(tasks_file)
        return tasks_json
    except JSONDecodeError as e:
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! This might be due to corruption of the file. Please backup from the previous commits in the git repository, if possible."
        )

        # return -1 to sys.exit(-1)
        return -1


@tasks.command()
@click.argument("name")
@click.argument("due_date")
@click.argument("priority")
@click.argument("group")
def add(name: str, due_date: str, priority: str, group: str) -> None:
    """Adds a new task to tasks.json and commits the task to the git repository.

    :param name: Name of the task.
    :type name: str
    :param due_date: Due date for the task.
    :type due_date: str
    :param priority: Priority for the task.
    :type priority: str
    :param group: Group for the task.
    :type group: str
    :rtype: None
    """

    words = group.split(" ")
    extracted_groups = [word[1:] for word in words if word[0] == "@"]

    task_date = parse_date(due_date)

    try:
        with tasks_path.open("r") as tasks_file:
            tasks_json = load_json(tasks_file)
            if tasks_json == -1:
                sys.exit(-1)

            task_id = len([task for task in tasks_json]) + 1
            content = {
                "id": ("#" + str(task_id)),
                "name": name,
                "date": str(datetime.now()),
                "due_date": str(task_date),
                "priority": priority.lower(),
                "group": extracted_groups,
            }

            tasks_json.append(content)

            with tasks_path.open("w") as tasks_file:
                tasks_json = json.dump(tasks_json, tasks_file)
                console.print(
                    f':white_check_mark: "{name}" has been added to the list!'
                )
                repo.index.add([str(tasks_path)])
                repo.index.commit(f'Added "{name}" in tasks.')
                console.print(
                    f':white_check_mark: "{name}" has been added to the git repository!'
                )

    except FileNotFoundError as e:
        with tasks_path.open("a") as tasks_file:
            tasks_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@tasks.command()
@click.argument("id")
@click.argument("name")
@click.argument("date")
@click.argument("priority")
@click.argument("group")
def edit(id: str, name: str, date: str, priority: str, group: str) -> None:
    """Edits an existing task in tasks.json and commits the changes in the git repository.

    :param id: ID of the task.
    :type id: str
    :param name: Name of the task.
    :type name: str
    :param date: Due date for the task.
    :type date: str
    :param priority: Priority for the task.
    :type priority: str
    :param group: Group for the task.
    :type group: str
    :rtype: None
    """

    words = group.split(" ")
    extracted_groups = [word[1:] for word in words if word[0] == "@"]

    try:
        with tasks_path.open("r") as tasks_file:
            tasks_json = load_json(tasks_file)
            if tasks_json == -1:
                sys.exit(-1)
            filtered_tasks = tasks_json

            for task in filtered_tasks:
                if task["id"] == id:
                    if date.strip() != ".":
                        task["due_date"] = str(parse_date(date, task["due_date"]))
                    if name.strip() != ".":
                        task["name"] = name

                    if priority.strip() != ".":
                        task["priority"] = priority

                    if group.strip() != ".":
                        task["group"] = extracted_groups

            with tasks_path.open("w") as tasks_file:
                filtered_tasks = json.dump(filtered_tasks, tasks_file)
                console.print(
                    f":white_check_mark: Task {id} has been modified in the list!"
                )
                repo.index.add([str(tasks_path)])
                repo.index.commit(f"Modified Task {id} in tasks.")
                console.print(
                    f":white_check_mark: Task {id} has been modified in the git repository!"
                )

    except FileNotFoundError as e:
        with tasks_path.open("a") as tasks_file:
            tasks_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
        )


@tasks.command()
@click.argument("id")
def delete(id: str) -> None:
    """Deletes a task from tasks.json

    :param id: ID of the task.
    :type id: str
    """

    try:
        tasks_json = None
        with tasks_path.open("r") as tasks_file:
            tasks_json = load_json(tasks_file)
            if tasks_json == -1:
                sys.exit(-1)

        filtered_tasks = [task for task in tasks_json if task["id"] != id]

        try:
            with tasks_path.open("w") as tasks_file:
                filtered_tasks = json.dump(filtered_tasks, tasks_file)
                repo.index.add([str(tasks_path)])
                repo.index.commit(f"Deleted Task {id} from tasks.")
                console.print(
                    f":white_check_mark: Task {id} has been removed from the git repository!"
                )
        except FileNotFoundError as e:
            logger.error(e)
            console.print(
                ":cross_mark: Failed to write to the file! Please check the logs in the home directory."
            )

    except FileNotFoundError as e:
        with tasks_path.open("a") as tasks_file:
            tasks_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )


@tasks.command()
def show() -> None:
    """Shows all tasks present in tasks.json"""

    try:
        with tasks_path.open("r") as tasks_file:
            file_content = load_json(tasks_file)
            if file_content == -1:
                sys.exit(-1)
            tasks_utils.parse_tasks(file_content)
    except FileNotFoundError as e:
        with tasks_path.open("a") as tasks_file:
            tasks_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )
        sys.exit(-1)


@tasks.command()
@click.argument("group_name")
def show_group(group_name: str) -> None:
    """Shows all tasks belonging to `group_name`

    :param group_name: Group name to which the task belongs.
    :type group_name: str
    :rtype: None
    """

    try:
        with tasks_path.open("r") as tasks_file:
            file_content = load_json(tasks_file)
            if file_content == -1:
                sys.exit(-1)

            filtered_tasks = []
            for task in file_content:
                for group in task["group"]:
                    if group_name[1:] == group:
                        filtered_tasks.append(task)

            # should return -1 for passing tests
            if filtered_tasks == []:
                sys.exit(-1)

            tasks_utils.parse_tasks(filtered_tasks)

    except FileNotFoundError as e:
        with tasks_path.open("a") as tasks_file:
            tasks_file.write("[]")
        logger.error(e)
        console.print(
            ":cross_mark: Failed to read from the file! Please check the logs in the home directory."
        )
        sys.exit(-1)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['absorb',
 'absorb.config',
 'absorb.core',
 'absorb.core.idea',
 'absorb.core.kanban',
 'absorb.core.tasks',
 'absorb.utils']

package_data = \
{'': ['*']}

install_requires = \
['GitPython>=3.1.17,<4.0.0',
 'Pygments>=2.9.0,<3.0.0',
 'click-plugins>=1.1.1,<2.0.0',
 'click>=8.0.1,<9.0.0',
 'colorama>=0.4.4,<0.5.0',
 'commonmark>=0.9.1,<0.10.0',
 'gitdb>=4.0.7,<5.0.0',
 'importlib-metadata>=4.5.0,<5.0.0',
 'python-json-logger>=2.0.1,<3.0.0',
 'rich>=10.3.0,<11.0.0',
 'smmap>=4.0.0,<5.0.0',
 'typing-extensions>=3.10.0,<4.0.0',
 'zipp>=3.4.1,<4.0.0']

entry_points = \
{'console_scripts': ['absorb = absorb.main:cli']}

setup_kwargs = {
    'name': 'absorb',
    'version': '0.1.1',
    'description': 'The extensible, feature-rich CLI workspace.',
    'long_description': None,
    'author': 'Aadhav Vignesh',
    'author_email': 'aadhav.n1@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# absorb/__init__.py
"""The extensible, feature-rich CLI workspace."""
try:
    from importlib.metadata import version, PackageNotFoundError  # type: ignore
except ImportError:
    from importlib_metadata import version, PackageNotFoundError  # type: ignore


try:
    __version__ = version(__name__)
except PackageNotFoundError:
    __version__ = "unknown"



import logging
from ..config.paths import LOGS_PATH
from pathlib import Path
from pythonjsonlogger import jsonlogger


def get_logger() -> logging.getLogger:
    """Initializes a logger which is utilized by the click commands.

    :return: Returns a logger.
    :rtype: logging.getLogger
    """

    # Initialize loggers
    logger = logging.getLogger(__name__)

    # Console handler
    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.WARNING)
    console_format = logging.Formatter("%(name)s - %(levelname)s - %(message)s")
    console_handler.setFormatter(console_format)

    # File handler
    try:
        file_handler = logging.FileHandler(str(LOGS_PATH / "absorb-logs.log"))
    except FileNotFoundError:
        Path(str(LOGS_PATH)).mkdir()
        Path(str(LOGS_PATH / "absorb-logs.log")).touch()
        file_handler = logging.FileHandler(str(LOGS_PATH / "absorb-logs.log"))

    file_handler.setLevel(logging.ERROR)

    JSON_formatter = jsonlogger.JsonFormatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )
    file_handler.setFormatter(JSON_formatter)

    # Add handlers to logger
    logger.addHandler(console_handler)
    logger.addHandler(file_handler)

    return logger
